Refresh

This website rubydoc.info/gems/background_queue/0.6.0/BackgroundQueue is currently offline. Cloudflare\'s Always Online™ shows a snapshot of this web page from the Internet Archive\'s Wayback Machine. To check for the live version, click Refresh.

Module: BackgroundQueue

Defined in:
lib/background_queue/client.rb,
lib/background_queue/utils.rb,
lib/background_queue/config.rb,
lib/background_queue/command.rb

Overview

The Background Queue will schedule tasks in the background. Refer to README for more details.

Defined Under Namespace

Modules: ClientLib, ServerLib, Utils, Worker Classes: Client, ClientException, Command, Config, InvalidCommand, LoadError